@@ -15,6 +15,7 @@
 #   Lars Buitinck
 #   Adam Retter, The National Archives, UK. <adam.retter@googlemail.com>
 #   Jaishree Davey, The National Archives, UK.
+#   Laura Damian, The National Archives, UK.
 #   Carl Wilson, Open Planets Foundation, UK.
 #
 # This program is free software: you can redistribute it and/or modify
@@ -53,7 +54,7 @@ scriptPath, scriptName = os.path.split(sys.argv[0])
 if len(scriptName) == 0:
     scriptName = 'jpylyzer'
 
-__version__ = "1.13.0"
+__version__ = "1.14.2"
 
 # Create parser
 parser = argparse.ArgumentParser(
@@ -274,7 +275,16 @@ def checkOneFile(file):
     characteristics.makeHumanReadable(remapTable)
 
     # Create output elementtree object
-    root = ET.Element('jpylyzer')
+
+    if config.inputRecursiveFlag or config.inputWrapperFlag:
+        # Name space already declared in results element, so no need to do it
+        # here
+        root = ET.Element('jpylyzer')
+    else:
+        root = ET.Element(
+        'jpylyzer', {'xmlns' : 'http://openpreservation.org/ns/jpylyzer/',
+        'xmlns:xsi' : 'http://www.w3.org/2001/XMLSchema-instance' ,
+        'xsi:schemaLocation' : 'http://openpreservation.org/ns/jpylyzer/ http://jpylyzer.openpreservation.org/jpylyzer-v-1-0.xsd'})
 
     # Create elements for storing tool and file meta info
     toolInfo = ET.Element('toolInfo')
@@ -409,7 +419,7 @@ def findFiles(recurse, paths):
 
             # If the input path is a directory, then glob expands it to full
             # name
-            if len(filesList) == 1:
+            if len(filesList) == 1 and os.path.isdir(filesList[0]):
                 # set root to the expanded directory path
                 root = filesList[0]
 
@@ -420,6 +430,10 @@ def findFiles(recurse, paths):
             """
 
             # If the input path returned files list, add files to List
+            
+            if len(filesList) == 1 and os.path.isfile(filesList[0]):
+                existingFiles.append(filesList[0])
+            
             if len(filesList) > 1:
                 for f in filesList:
                     if os.path.isfile(f):
@@ -430,7 +444,7 @@ def findFiles(recurse, paths):
             msg = root + " does not exist"
             printWarning(msg)
 
-        """ Disabled JvdK: 
+        """ Disabled JvdK:
         elif os.path.isdir(root) and not recurse:
             #input path is a directory and is not recursive
             getFilesFromDir(root)
@@ -471,16 +485,15 @@ def findFiles(recurse, paths):
             elif os.path.isdir(root):
                 getFilesFromTree(root)
 
-
-def writeElement(elt,codec):
+def writeElement(elt, codec):
     # Writes element as XML to stdout using defined codec
-    
+
     # Element to string
     if config.PYTHON_VERSION.startswith(config.PYTHON_2):
         xmlOut = ET.tostring(elt, 'UTF-8', 'xml')
     if config.PYTHON_VERSION.startswith(config.PYTHON_3):
         xmlOut = ET.tostring(elt, 'unicode', 'xml')
-    
+
     if config.noPrettyXMLFlag == False:
         # Make xml pretty
         xmlPretty = minidom.parseString(xmlOut).toprettyxml('    ')
@@ -506,7 +519,7 @@ def writeElement(elt,codec):
         if config.PYTHON_VERSION.startswith(config.PYTHON_3):
             codec.write(xmlOut)
 
-            
+
 def checkFiles(recurse, wrap, paths):
     # This method checks the input argument path(s) for existing files and
     # analyses them
@@ -524,25 +537,29 @@ def checkFiles(recurse, wrap, paths):
         out = codecs.getwriter(config.UTF8_ENCODING)(sys.stdout.buffer)
 
     # Wrap the xml output in <results> element, if wrapper flag is true
-    if wrap:
-        out.write("<?xml version='1.0' encoding='UTF-8'?>\n<results>\n")
+    if wrap or recurse:
+        xmlHead = "<?xml version='1.0' encoding='UTF-8'?>\n"
+        xmlHead += "<results xmlns=\"http://openpreservation.org/ns/jpylyzer/\"\n"
+        xmlHead += "xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\"\n"
+        xmlHead += "xsi:schemaLocation=\"http://openpreservation.org/ns/jpylyzer/ http://jpylyzer.openpreservation.org/jpylyzer-v-1-0.xsd\">\n"
     else:
-        out.write("<?xml version='1.0' encoding='UTF-8'?>\n")
+        xmlHead = "<?xml version='1.0' encoding='UTF-8'?>\n"
+    out.write(xmlHead)
 
     # Process the input files
     for path in existingFiles:
 
         # Analyse file
         xmlElement = checkOneFile(path)
-        
+
         # Write output to stdout
-        writeElement(xmlElement,out)
-        
+        writeElement(xmlElement, out)
+
     # Close </results> element if wrapper flag is true
-    if wrap:
+    if wrap or recurse:
         out.write("</results>\n")
 
-            
+
 def parseCommandLine():
     # Add arguments
     parser.add_argument('--verbose',
@@ -550,13 +567,12 @@ def parseCommandLine():
                         dest="outputVerboseFlag",
                         default=False,
                         help="report test results in verbose format")
-    """
-    parser.add_argument('--recursive', '-r', 
-        action = "store_true", 
-        dest = "inputRecursiveFlag", 
-        default = False, 
-        help = "when encountering a folder, every file in every subfolder will be analysed")
-    """
+
+    parser.add_argument('--recurse', '-r',
+                        action="store_true",
+                        dest="inputRecursiveFlag",
+                        default=False,
+                        help="when analysing a directory, recurse into subdirectories (implies --wrapper)")
     parser.add_argument('--wrapper',
                         '-w', action="store_true",
                         dest="inputWrapperFlag",
@@ -575,7 +591,7 @@ def parseCommandLine():
     parser.add_argument('jp2In',
                         action="store",
                         type=str,
-                        nargs=argparse.REMAINDER,
+                        nargs='+',
                         help="input JP2 image(s), may be one or more (whitespace-separated) path expressions; prefix wildcard (*) with backslash (\\) in Linux")
     parser.add_argument('--version', '-v',
                         action='version',
@@ -602,11 +618,14 @@ def main():
     # (here: 'boxvalidator.py')
     config.outputVerboseFlag = args.outputVerboseFlag
     config.extractNullTerminatedXMLFlag = args.extractNullTerminatedXMLFlag
+    config.inputRecursiveFlag = args.inputRecursiveFlag
+    config.inputWrapperFlag = args.inputWrapperFlag
+    config.extractNullTerminatedXMLFlag = args.extractNullTerminatedXMLFlag
     config.noPrettyXMLFlag = args.noPrettyXMLFlag
 
     # Check files
-    #checkFiles(args.inputRecursiveFlag, args.inputWrapperFlag, jp2In)
-    checkFiles(False, args.inputWrapperFlag, jp2In)
+    checkFiles(args.inputRecursiveFlag, args.inputWrapperFlag, jp2In)
+    # checkFiles(False, args.inputWrapperFlag, jp2In)
 
 if __name__ == "__main__":
     main()
